@@ -26,14 +26,15 @@
 
 #include "plugin.h"
 
-#define GRAPHITE_STORE_RATES        0x01
+#define GRAPHITE_STORE_RATES 0x01
 #define GRAPHITE_SEPARATE_INSTANCES 0x02
-#define GRAPHITE_ALWAYS_APPEND_DS   0x04
+#define GRAPHITE_ALWAYS_APPEND_DS 0x04
+#define GRAPHITE_DROP_DUPE_FIELDS 0x08
+#define GRAPHITE_PRESERVE_SEPARATOR 0x10
 
-int format_graphite (char *buffer,
-    size_t buffer_size, const data_set_t *ds,
-    const value_list_t *vl, const char *prefix,
-    const char *postfix, const char escape_char,
-    unsigned int flags);
+int format_graphite(char *buffer, size_t buffer_size, const data_set_t *ds,
+                    const value_list_t *vl, const char *prefix,
+                    const char *postfix, const char escape_char,
+                    unsigned int flags);
 
 #endif /* UTILS_FORMAT_GRAPHITE_H */
